/**
 *
 * @file 6channel_mixer.h
 *
 * @brief  AIC3268 Configuration for 8 channel mixer
 *
 * @copyright Copyright (C) 2021 Texas Instruments Incorporated - http://www.ti.com/
 * All rights reserved.
 *
 * Software License Agreement
 * Texas Instruments (TI) is supplying this software for use solely and
 * exclusively on TI's Microcontroller and/or Data Converter products.
 * The software is owned by TI and/or its suppliers, and is protected
 * under applicable @copyright Copyright laws.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITH ALL FAULTS.
 * NO WARRANTIES, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT
 * NOT LIMITED TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. TI SHALL NOT, UNDER ANY
 * CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR CONSEQUENTIAL
 * DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 */
#include <string.h>

//INSTRUCTIONS & COEFFICIENTS


static const reg_value REG_Section_program[] = {
    {  0,0x0},
    {  0x7F,0x00},
//			# Set AutoINC
    {121,0x01},
//			# reg[0][0][1] = 0x01                        ; reg(0)(1)(0x00 => 0 )     S/W Reset
    {  1,0x01},
//			# reg[0][0][4] = 0x33                        ; ADC_CLKIN = PLL_MCLK, DAC_CLKIN = PLL_MCLK
    {  4,0x33},
//			# reg[0][0][5] = 0x00                        ; PLL_CLKIN = MCLK1
    {  5,0x00},
//			# reg[0][0][6] = 0x91                        ; P=1, R=1
    {  6,0x91},
//			# reg[0][0][7]  = 0x08             ; P=1, R=1, J=8
    {  7,0x08},
//			# reg[0][0][13] = 0x00             ; DOSR = 128 (MSB)
    { 13,0x00},
//			# reg[0][0][14] = 0x80             ; DOSR = 128 (LSB)
    { 14,0x80},
//			# reg[0][0][18] = 0x02             ; NADC Powerdown NADC = 2
    { 18,0x02},
//			# reg[0][0][19] = 0x90             ; MADC Powerup MADC = 16
    { 19,0x90},
//			# reg[0][0][20] = 0x40             ; AOSR = 64
    { 20,0x40},
//			# reg[0][0][11] = 0x82             ; NDAC = 2, divider powered on
    { 11,0x82},
//			# reg[0][0][8] = 0x00                        ; D=0000 (MSB)
    {  8,0x00},
//			# reg[0][0][9] = 0x00                        ; D=0000 (LSB)
    {  9,0x00},
//			# reg[0][0][12] = 0x88                       ; reg(0)(0)(0x0c => 12)     DAC Powerup MDAC = 8
    { 12,0x88},
    {  0x7F,0x78},
//			# reg[120][0][50] = 0x88                     ; Interpolation Ratio is 8, FIFO = Enabled
    { 50,0x88},
    {  0x7F,0x64},
//			# reg[100][0][50] = 0xa4                     ; Decimation Ratio is 4, CIC AutoNorm = Enabled, FIFO Enabled
    { 50,0xA4},
    {  0x7F,0x00},
//			# reg[0][0][61] = 0x00                       ; reg(0)(0)(0x3d => 61)     ADC prog mode
    { 61,0x00},
//			# reg[0][0][83] = 0x0                    ; adc vol control = 0db
    { 83,0x00},
//			# reg[0][0][84] = 0x0                    ; adc vol control = 0db
    { 84,0x00},
    {  0,0x01},
//			# reg[0][1][1 ] = 0x00                       ; reg(0)(1)(0x01 => 0 )     Crude avdd disabled
    {  1,0x00},
//			# reg[0][1][3 ] = 0x00                       ; reg(0)(1)(0x03 => 3 )     LDAC FIR
    {  3,0x00},
//			# reg[0][1][4 ] = 0x00                       ; reg(0)(1)(0x04 => 4 )     RDAC FIR
    {  4,0x00},
//			# reg[0][1][121] = 0x33                      ; reg(0)(1)(0x79 => 121)    Quick charge time for Mic inputs
    {121,0x33},
//			# reg[0][1][122] = 0x01                      ; reg(0)(1)(0x7A => 122)    Vref charge time - 40 ms.
    {122,0x01},
    {  0,0x00},
//			# reg[0][0][60] = 0x00				  ; reg(0)(0)(0x3C => 60)	  miniDSP_D used for processing
    { 60,0x00},
    {  0x7F,0x78},
//			# reg[120][0][24]=0x80
    { 24,0x80},
    {255,0x00},
    {255,0x01},
    {  0,0x0},
    {  0x7F,0x28},
//			# reg[40][0][1] = 0x04                        ; adaptive mode for ADC
    {  1,0x04},
    {  0x7F,0x50},
//			# reg[80][0][1] = 0x04                        ; adaptive mode for DAC
    {  1,0x04},
    {  0x7F,0x64},
//			# reg[100][0][48] = 4
    { 48,0x04},
//			# reg[100][0][49] = 0
    { 49,0x00},
    {  0x7F,0x78},
//			# reg[120][0][48] = 4
    { 48,0x04},
//			# reg[120][0][49] = 0
    { 49,0x00},
    {  0x7F,0x00},
//			# reg[0][0][63] = 0xc2                       ; reg(0)(0)(0x3f => 63)     DAC L&R DAC powerup Ldata-LDAC Rdata-RDAC (soft-stepping disable)
    { 63,0xC2},
//			# reg[0][0][64] = 0x00                       ; reg(0)(0)(0x40 => 64)     DAC Left and Right DAC unmuted with indep.  vol. ctrl
    { 64,0x00},
    {  0,0x01},
//			# reg[0][1][22] = 0xc3				  ; reg(0)(1)(0x16 => 22)	  Left and Right DACs to LOR/L
    { 22,0xC3},
    {  0,0x04},
//			# reg[0][4][1]  = 0x20                       ; ASI1 Audio Interface = DSP mode 16-bit
    {  1,0x20},
//			# reg[0][4][4]  = 0xc0				  ; 4-pair of left and right channel enabled for ASI1
    {  4,0xC0},
//			# reg[0][4][10] = 0                          ; ASI1 Audio Interface WCLK and BCLK
    { 10,0x00},
//			# reg[0][4][8]  = 0x50                       ; ASI1 Left DAC Datapath = Left Data, ASI1 Right DAC Datapath = Right Data
    {  8,0x50},
};

static const reg_value miniDSP_A_reg_values[] = {
    {  0,0x0},
    {  0x7F,0x28},
    {  0,0x01},
    {  8,0xFF},
    {  9,0xFF},
    { 10,0xFF},
    { 11,0x00},
    { 12,0x80},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x7F},
    { 17,0xFF},
    { 18,0xFF},
    { 19,0x00},
    { 20,0x40},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    {  0,0x09},
    { 72,0xFF},
    { 73,0xFF},
    { 74,0xFF},
    { 75,0x00},
    { 76,0x80},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0x7F},
    { 81,0xFF},
    { 82,0xFF},
    { 83,0x00},
    { 84,0x40},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0x00},
    { 90,0x00},
    { 91,0x00},
    {  0,0x0},
    {  0x7F,0x14},
    {  0,0x01},
    {  8,0xC0},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    {  0,0x0},
    {  0x7F,0x64},
    {  0,0x01},
    {  8,0x00},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x02},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
};
#define miniDSP_A_reg_values_COEFF_START   0
#define miniDSP_A_reg_values_COEFF_SIZE    51
#define miniDSP_A_reg_values_INST_START    51
#define miniDSP_A_reg_values_INST_SIZE     23

static const reg_value miniDSP_D_reg_values[] = {
    {  0,0x0},
    {  0x7F,0x50},
    {  0,0x01},
    {  8,0xFF},
    {  9,0xFF},
    { 10,0xFF},
    { 11,0x00},
    { 12,0x80},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x40},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x7F},
    { 21,0xF7},
    { 22,0x00},
    { 23,0x00},
    { 24,0x80},
    { 25,0x09},
    { 26,0x00},
    { 27,0x00},
    { 28,0x7F},
    { 29,0xEF},
    { 30,0x00},
    { 31,0x00},
    { 32,0x20},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x20},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x20},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x20},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x7F},
    { 49,0xFF},
    { 50,0xFF},
    { 51,0x00},
    { 52,0x20},
    { 53,0x00},
    { 54,0x00},
    { 55,0x00},
    { 56,0x20},
    { 57,0x00},
    { 58,0x00},
    { 59,0x00},
    { 60,0x20},
    { 61,0x00},
    { 62,0x00},
    { 63,0x00},
    { 64,0x20},
    { 65,0x00},
    { 66,0x00},
    { 67,0x00},
    { 68,0x00},
    { 69,0x00},
    { 70,0x00},
    { 71,0x00},
    { 72,0x40},
    { 73,0x00},
    { 74,0x00},
    { 75,0x00},
    { 76,0x40},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0x00},
    { 81,0x0D},
    { 82,0x00},
    { 83,0x00},
    { 84,0x00},
    { 85,0x1C},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0x3E},
    { 90,0x00},
    { 91,0x00},
    { 92,0x00},
    { 93,0x78},
    { 94,0x00},
    { 95,0x00},
    { 96,0x02},
    { 97,0x4C},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0xD5},
    {102,0x00},
    {103,0x00},
    {104,0x01},
    {105,0x65},
    {106,0x00},
    {107,0x00},
    {108,0x03},
    {109,0xE9},
    {110,0x00},
    {111,0x00},
    {112,0x07},
    {113,0xCA},
    {114,0x00},
    {115,0x00},
    {116,0xFF},
    {117,0xEF},
    {118,0x00},
    {119,0x00},
    {120,0xFE},
    {121,0xEB},
    {122,0x00},
    {123,0x00},
    {124,0xFF},
    {125,0xA8},
    {126,0x00},
    {127,0x00},
    {  0,0x02},
    {  8,0xFD},
    {  9,0x08},
    { 10,0x00},
    { 11,0x00},
    { 12,0xFF},
    { 13,0x5E},
    { 14,0x00},
    { 15,0x00},
    { 16,0xFF},
    { 17,0xD5},
    { 18,0x00},
    { 19,0x00},
    { 20,0xFE},
    { 21,0x36},
    { 22,0x00},
    { 23,0x00},
    { 24,0xFA},
    { 25,0xAC},
    { 26,0x00},
    { 27,0x00},
    { 28,0xF2},
    { 29,0xA3},
    { 30,0x00},
    { 31,0x00},
    { 32,0x28},
    { 33,0xAB},
    { 34,0x00},
    { 35,0x00},
    { 36,0x3F},
    { 37,0xFF},
    { 38,0x00},
    { 39,0x00},
    { 40,0xFF},
    { 41,0x98},
    { 42,0x00},
    { 43,0x00},
    { 44,0xF6},
    { 45,0xF9},
    { 46,0x00},
    { 47,0x00},
    { 48,0x26},
    { 49,0xFB},
    { 50,0x00},
    { 51,0x00},
    { 52,0x02},
    { 53,0x72},
    { 54,0x00},
    { 55,0x00},
    { 56,0x40},
    { 57,0x02},
    { 58,0x00},
    { 59,0x00},
    { 60,0xFB},
    { 61,0xCB},
    { 62,0x00},
    { 63,0x00},
    { 64,0x20},
    { 65,0xA7},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0x6A},
    { 70,0x00},
    { 71,0x00},
    { 72,0x3A},
    { 73,0x0F},
    { 74,0x00},
    { 75,0x00},
    {  0,0x09},
    { 72,0xFF},
    { 73,0xFF},
    { 74,0xFF},
    { 75,0x00},
    { 76,0x80},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0x40},
    { 81,0x00},
    { 82,0x00},
    { 83,0x00},
    { 84,0x7F},
    { 85,0xF7},
    { 86,0x00},
    { 87,0x00},
    { 88,0x80},
    { 89,0x09},
    { 90,0x00},
    { 91,0x00},
    { 92,0x7F},
    { 93,0xEF},
    { 94,0x00},
    { 95,0x00},
    { 96,0x20},
    { 97,0x00},
    { 98,0x00},
    { 99,0x00},
    {100,0x20},
    {101,0x00},
    {102,0x00},
    {103,0x00},
    {104,0x20},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x20},
    {109,0x00},
    {110,0x00},
    {111,0x00},
    {112,0x7F},
    {113,0xFF},
    {114,0xFF},
    {115,0x00},
    {116,0x20},
    {117,0x00},
    {118,0x00},
    {119,0x00},
    {120,0x20},
    {121,0x00},
    {122,0x00},
    {123,0x00},
    {124,0x20},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x0A},
    {  8,0x20},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x40},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x40},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x0D},
    { 26,0x00},
    { 27,0x00},
    { 28,0x00},
    { 29,0x1C},
    { 30,0x00},
    { 31,0x00},
    { 32,0x00},
    { 33,0x3E},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x78},
    { 38,0x00},
    { 39,0x00},
    { 40,0x02},
    { 41,0x4C},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0xD5},
    { 46,0x00},
    { 47,0x00},
    { 48,0x01},
    { 49,0x65},
    { 50,0x00},
    { 51,0x00},
    { 52,0x03},
    { 53,0xE9},
    { 54,0x00},
    { 55,0x00},
    { 56,0x07},
    { 57,0xCA},
    { 58,0x00},
    { 59,0x00},
    { 60,0xFF},
    { 61,0xEF},
    { 62,0x00},
    { 63,0x00},
    { 64,0xFE},
    { 65,0xEB},
    { 66,0x00},
    { 67,0x00},
    { 68,0xFF},
    { 69,0xA8},
    { 70,0x00},
    { 71,0x00},
    { 72,0xFD},
    { 73,0x08},
    { 74,0x00},
    { 75,0x00},
    { 76,0xFF},
    { 77,0x5E},
    { 78,0x00},
    { 79,0x00},
    { 80,0xFF},
    { 81,0xD5},
    { 82,0x00},
    { 83,0x00},
    { 84,0xFE},
    { 85,0x36},
    { 86,0x00},
    { 87,0x00},
    { 88,0xFA},
    { 89,0xAC},
    { 90,0x00},
    { 91,0x00},
    { 92,0xF2},
    { 93,0xA3},
    { 94,0x00},
    { 95,0x00},
    { 96,0x28},
    { 97,0xAB},
    { 98,0x00},
    { 99,0x00},
    {100,0x3F},
    {101,0xFF},
    {102,0x00},
    {103,0x00},
    {104,0xFF},
    {105,0x98},
    {106,0x00},
    {107,0x00},
    {108,0xF6},
    {109,0xF9},
    {110,0x00},
    {111,0x00},
    {112,0x26},
    {113,0xFB},
    {114,0x00},
    {115,0x00},
    {116,0x02},
    {117,0x72},
    {118,0x00},
    {119,0x00},
    {120,0x40},
    {121,0x02},
    {122,0x00},
    {123,0x00},
    {124,0xFB},
    {125,0xCB},
    {126,0x00},
    {127,0x00},
    {  0,0x0B},
    {  8,0x20},
    {  9,0xA7},
    { 10,0x00},
    { 11,0x00},
    { 12,0xFF},
    { 13,0x6A},
    { 14,0x00},
    { 15,0x00},
    { 16,0x3A},
    { 17,0x0F},
    { 18,0x00},
    { 19,0x00},
    {  0,0x0},
    {  0x7F,0x3C},
    {  0,0x01},
    {  8,0xC0},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0xC0},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    {  0,0x0},
    {  0x7F,0x78},
    {  0,0x01},
    {  8,0x04},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0x04},
    { 13,0x00},
    { 14,0x20},
    { 15,0x01},
    { 16,0x04},
    { 17,0x02},
    { 18,0x00},
    { 19,0x02},
    { 20,0x04},
    { 21,0x02},
    { 22,0x20},
    { 23,0x03},
    { 24,0x04},
    { 25,0x02},
    { 26,0x40},
    { 27,0x04},
    { 28,0x04},
    { 29,0x02},
    { 30,0x60},
    { 31,0x05},
    { 32,0x04},
    { 33,0x02},
    { 34,0x80},
    { 35,0x06},
    { 36,0x04},
    { 37,0x02},
    { 38,0xA0},
    { 39,0x07},
    { 40,0x60},
    { 41,0x64},
    { 42,0xC0},
    { 43,0x00},
    { 44,0x48},
    { 45,0x01},
    { 46,0xA0},
    { 47,0x00},
    { 48,0x45},
    { 49,0x02},
    { 50,0x20},
    { 51,0x0A},
    { 52,0x00},
    { 53,0x00},
    { 54,0x00},
    { 55,0x00},
    { 56,0x10},
    { 57,0x00},
    { 58,0x00},
    { 59,0x00},
    { 60,0x10},
    { 61,0x00},
    { 62,0x00},
    { 63,0x01},
    { 64,0x10},
    { 65,0x00},
    { 66,0x00},
    { 67,0x02},
    { 68,0x10},
    { 69,0x00},
    { 70,0x00},
    { 71,0x03},
    { 72,0x10},
    { 73,0x00},
    { 74,0x00},
    { 75,0x04},
    { 76,0x10},
    { 77,0x00},
    { 78,0x00},
    { 79,0x05},
    { 80,0x10},
    { 81,0x00},
    { 82,0x00},
    { 83,0x06},
    { 84,0x10},
    { 85,0x00},
    { 86,0x00},
    { 87,0x07},
    { 88,0x44},
    { 89,0x00},
    { 90,0x00},
    { 91,0x0A},
    { 92,0x00},
    { 93,0x00},
    { 94,0x00},
    { 95,0x00},
    { 96,0x00},
    { 97,0x00},
    { 98,0x00},
    { 99,0x00},
    {100,0x00},
    {101,0x00},
    {102,0x00},
    {103,0x00},
    {104,0x00},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x00},
    {109,0x00},
    {110,0x00},
    {111,0x00},
    {112,0x00},
    {113,0x00},
    {114,0x00},
    {115,0x00},
    {116,0x00},
    {117,0x00},
    {118,0x00},
    {119,0x00},
    {120,0x00},
    {121,0x00},
    {122,0x00},
    {123,0x00},
    {124,0x00},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x02},
    {  8,0x00},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0x18},
    { 13,0x00},
    { 14,0xC0},
    { 15,0x00},
    { 16,0x1C},
    { 17,0x00},
    { 18,0xE0},
    { 19,0x01},
    { 20,0x1C},
    { 21,0x01},
    { 22,0x00},
    { 23,0x02},
    { 24,0x1C},
    { 25,0x01},
    { 26,0x20},
    { 27,0x03},
    { 28,0x00},
    { 29,0x00},
    { 30,0x00},
    { 31,0x00},
    { 32,0x00},
    { 33,0x00},
    { 34,0x00},
    { 35,0x00},
    { 36,0x00},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x10},
    { 41,0x00},
    { 42,0x00},
    { 43,0x08},
    { 44,0x18},
    { 45,0x01},
    { 46,0x60},
    { 47,0x04},
    { 48,0x1C},
    { 49,0x01},
    { 50,0x80},
    { 51,0x05},
    { 52,0x1C},
    { 53,0x01},
    { 54,0xA0},
    { 55,0x06},
    { 56,0x1C},
    { 57,0x01},
    { 58,0xC0},
    { 59,0x07},
    { 60,0x00},
    { 61,0x00},
    { 62,0x00},
    { 63,0x00},
    { 64,0x00},
    { 65,0x00},
    { 66,0x00},
    { 67,0x00},
    { 68,0x00},
    { 69,0x00},
    { 70,0x00},
    { 71,0x00},
    { 72,0x10},
    { 73,0x00},
    { 74,0x00},
    { 75,0x09},
    { 76,0x18},
    { 77,0x02},
    { 78,0x00},
    { 79,0x08},
    { 80,0x1C},
    { 81,0x02},
    { 82,0x20},
    { 83,0x09},
    { 84,0x00},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0x00},
    { 90,0x00},
    { 91,0x00},
    { 92,0x00},
    { 93,0x00},
    { 94,0x00},
    { 95,0x00},
    { 96,0x10},
    { 97,0x00},
    { 98,0x00},
    { 99,0x0A},
    {100,0x58},
    {101,0x60},
    {102,0x08},
    {103,0x01},
    {104,0x60},
    {105,0x60},
    {106,0x00},
    {107,0x00},
    {108,0x58},
    {109,0x60},
    {110,0x00},
    {111,0x0F},
    {112,0x00},
    {113,0x00},
    {114,0x00},
    {115,0x00},
    {116,0x44},
    {117,0x00},
    {118,0xC0},
    {119,0x16},
    {120,0x08},
    {121,0x00},
    {122,0x00},
    {123,0x4A},
    {124,0x08},
    {125,0x00},
    {126,0x20},
    {127,0x8A},
    {  0,0x03},
    {  8,0x08},
    {  9,0x00},
    { 10,0x00},
    { 11,0x49},
    { 12,0x08},
    { 13,0x00},
    { 14,0x20},
    { 15,0x89},
    { 16,0x08},
    { 17,0x00},
    { 18,0x00},
    { 19,0x48},
    { 20,0x08},
    { 21,0x00},
    { 22,0x20},
    { 23,0x88},
    { 24,0x08},
    { 25,0x00},
    { 26,0x00},
    { 27,0x47},
    { 28,0x08},
    { 29,0x00},
    { 30,0x20},
    { 31,0x87},
    { 32,0x08},
    { 33,0x00},
    { 34,0x00},
    { 35,0x46},
    { 36,0x08},
    { 37,0x00},
    { 38,0x20},
    { 39,0x86},
    { 40,0x08},
    { 41,0x00},
    { 42,0x00},
    { 43,0x45},
    { 44,0x08},
    { 45,0x00},
    { 46,0x20},
    { 47,0x85},
    { 48,0x08},
    { 49,0x00},
    { 50,0x00},
    { 51,0x44},
    { 52,0x08},
    { 53,0x00},
    { 54,0x20},
    { 55,0x84},
    { 56,0x08},
    { 57,0x00},
    { 58,0x00},
    { 59,0x43},
    { 60,0x08},
    { 61,0x00},
    { 62,0x20},
    { 63,0x83},
    { 64,0x00},
    { 65,0x00},
    { 66,0x00},
    { 67,0x00},
    { 68,0x00},
    { 69,0x00},
    { 70,0x00},
    { 71,0x00},
    { 72,0x00},
    { 73,0x00},
    { 74,0x00},
    { 75,0x00},
    { 76,0x00},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0x00},
    { 81,0x00},
    { 82,0x00},
    { 83,0x00},
    { 84,0x44},
    { 85,0x00},
    { 86,0x00},
    { 87,0x06},
    { 88,0x21},
    { 89,0x00},
    { 90,0x20},
    { 91,0x00},
    { 92,0x4B},
    { 93,0x00},
    { 94,0xC0},
    { 95,0x00},
    { 96,0x4B},
    { 97,0x00},
    { 98,0xE0},
    { 99,0x00},
    {100,0x00},
    {101,0x00},
    {102,0x40},
    {103,0x48},
    {104,0x0C},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x0C},
    {109,0x00},
    {110,0x20},
    {111,0x00},
    {112,0x18},
    {113,0x00},
    {114,0x40},
    {115,0x0A},
    {116,0x18},
    {117,0x00},
    {118,0x40},
    {119,0x0A},
    {120,0x18},
    {121,0x00},
    {122,0x80},
    {123,0x0E},
    {124,0x1C},
    {125,0x00},
    {126,0xA0},
    {127,0x10},
    {  0,0x04},
    {  8,0x10},
    {  9,0x00},
    { 10,0x20},
    { 11,0x0D},
    { 12,0x10},
    { 13,0x00},
    { 14,0x20},
    { 15,0x4B},
    { 16,0x1C},
    { 17,0x00},
    { 18,0x60},
    { 19,0x0D},
    { 20,0x18},
    { 21,0x00},
    { 22,0x80},
    { 23,0x4C},
    { 24,0x1C},
    { 25,0x00},
    { 26,0xA0},
    { 27,0x50},
    { 28,0x1C},
    { 29,0x00},
    { 30,0x60},
    { 31,0x4B},
    { 32,0x10},
    { 33,0x30},
    { 34,0x00},
    { 35,0x0F},
    { 36,0x00},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x00},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x10},
    { 45,0x30},
    { 46,0x00},
    { 47,0x4F},
    { 48,0x18},
    { 49,0x02},
    { 50,0x40},
    { 51,0x34},
    { 52,0x1C},
    { 53,0x02},
    { 54,0x60},
    { 55,0x11},
    { 56,0x1C},
    { 57,0x02},
    { 58,0x40},
    { 59,0x0F},
    { 60,0x1C},
    { 61,0x02},
    { 62,0x60},
    { 63,0x32},
    { 64,0x1C},
    { 65,0x02},
    { 66,0x80},
    { 67,0x13},
    { 68,0x1C},
    { 69,0x02},
    { 70,0x80},
    { 71,0x30},
    { 72,0x1C},
    { 73,0x02},
    { 74,0xA0},
    { 75,0x15},
    { 76,0x1C},
    { 77,0x02},
    { 78,0xA0},
    { 79,0x2E},
    { 80,0x1C},
    { 81,0x02},
    { 82,0xC0},
    { 83,0x1B},
    { 84,0x1C},
    { 85,0x02},
    { 86,0xC0},
    { 87,0x28},
    { 88,0x1C},
    { 89,0x02},
    { 90,0xE0},
    { 91,0x17},
    { 92,0x1C},
    { 93,0x02},
    { 94,0xE0},
    { 95,0x2C},
    { 96,0x1C},
    { 97,0x03},
    { 98,0x00},
    { 99,0x19},
    {100,0x1C},
    {101,0x03},
    {102,0x00},
    {103,0x2A},
    {104,0x1C},
    {105,0x03},
    {106,0x20},
    {107,0x1D},
    {108,0x1C},
    {109,0x03},
    {110,0x20},
    {111,0x26},
    {112,0x1C},
    {113,0x03},
    {114,0x40},
    {115,0x1F},
    {116,0x1C},
    {117,0x03},
    {118,0x40},
    {119,0x24},
    {120,0x1C},
    {121,0x03},
    {122,0x60},
    {123,0x10},
    {124,0x1C},
    {125,0x03},
    {126,0x60},
    {127,0x33},
    {  0,0x05},
    {  8,0x1C},
    {  9,0x03},
    { 10,0x80},
    { 11,0x18},
    { 12,0x1C},
    { 13,0x03},
    { 14,0x80},
    { 15,0x2B},
    { 16,0x1C},
    { 17,0x03},
    { 18,0xA0},
    { 19,0x14},
    { 20,0x1C},
    { 21,0x03},
    { 22,0xA0},
    { 23,0x2F},
    { 24,0x1C},
    { 25,0x03},
    { 26,0xC0},
    { 27,0x1C},
    { 28,0x1C},
    { 29,0x03},
    { 30,0xC0},
    { 31,0x27},
    { 32,0x1C},
    { 33,0x03},
    { 34,0xE0},
    { 35,0x16},
    { 36,0x1C},
    { 37,0x03},
    { 38,0xE0},
    { 39,0x2D},
    { 40,0x1C},
    { 41,0x04},
    { 42,0x00},
    { 43,0x12},
    { 44,0x1C},
    { 45,0x04},
    { 46,0x00},
    { 47,0x31},
    { 48,0x1C},
    { 49,0x04},
    { 50,0x20},
    { 51,0x1A},
    { 52,0x1C},
    { 53,0x04},
    { 54,0x20},
    { 55,0x29},
    { 56,0x1C},
    { 57,0x04},
    { 58,0x40},
    { 59,0x1E},
    { 60,0x1C},
    { 61,0x04},
    { 62,0x40},
    { 63,0x25},
    { 64,0x1C},
    { 65,0x04},
    { 66,0x60},
    { 67,0x20},
    { 68,0x1C},
    { 69,0x04},
    { 70,0x60},
    { 71,0x23},
    { 72,0x1C},
    { 73,0x04},
    { 74,0x80},
    { 75,0x21},
    { 76,0x1C},
    { 77,0x04},
    { 78,0x80},
    { 79,0x22},
    { 80,0x00},
    { 81,0x00},
    { 82,0x00},
    { 83,0x00},
    { 84,0x00},
    { 85,0x00},
    { 86,0x00},
    { 87,0x00},
    { 88,0x00},
    { 89,0x00},
    { 90,0x00},
    { 91,0x00},
    { 92,0x10},
    { 93,0x00},
    { 94,0x00},
    { 95,0x39},
    { 96,0x18},
    { 97,0x02},
    { 98,0x40},
    { 99,0x74},
    {100,0x1C},
    {101,0x02},
    {102,0x60},
    {103,0x51},
    {104,0x1C},
    {105,0x02},
    {106,0x40},
    {107,0x4F},
    {108,0x1C},
    {109,0x02},
    {110,0x60},
    {111,0x72},
    {112,0x1C},
    {113,0x02},
    {114,0x80},
    {115,0x53},
    {116,0x1C},
    {117,0x02},
    {118,0x80},
    {119,0x70},
    {120,0x1C},
    {121,0x02},
    {122,0xA0},
    {123,0x55},
    {124,0x1C},
    {125,0x02},
    {126,0xA0},
    {127,0x6E},
    {  0,0x06},
    {  8,0x1C},
    {  9,0x02},
    { 10,0xC0},
    { 11,0x5B},
    { 12,0x1C},
    { 13,0x02},
    { 14,0xC0},
    { 15,0x68},
    { 16,0x1C},
    { 17,0x02},
    { 18,0xE0},
    { 19,0x57},
    { 20,0x1C},
    { 21,0x02},
    { 22,0xE0},
    { 23,0x6C},
    { 24,0x1C},
    { 25,0x03},
    { 26,0x00},
    { 27,0x59},
    { 28,0x1C},
    { 29,0x03},
    { 30,0x00},
    { 31,0x6A},
    { 32,0x1C},
    { 33,0x03},
    { 34,0x20},
    { 35,0x5D},
    { 36,0x1C},
    { 37,0x03},
    { 38,0x20},
    { 39,0x66},
    { 40,0x1C},
    { 41,0x03},
    { 42,0x40},
    { 43,0x5F},
    { 44,0x1C},
    { 45,0x03},
    { 46,0x40},
    { 47,0x64},
    { 48,0x1C},
    { 49,0x03},
    { 50,0x60},
    { 51,0x50},
    { 52,0x1C},
    { 53,0x03},
    { 54,0x60},
    { 55,0x73},
    { 56,0x1C},
    { 57,0x03},
    { 58,0x80},
    { 59,0x58},
    { 60,0x1C},
    { 61,0x03},
    { 62,0x80},
    { 63,0x6B},
    { 64,0x1C},
    { 65,0x03},
    { 66,0xA0},
    { 67,0x54},
    { 68,0x1C},
    { 69,0x03},
    { 70,0xA0},
    { 71,0x6F},
    { 72,0x1C},
    { 73,0x03},
    { 74,0xC0},
    { 75,0x5C},
    { 76,0x1C},
    { 77,0x03},
    { 78,0xC0},
    { 79,0x67},
    { 80,0x1C},
    { 81,0x03},
    { 82,0xE0},
    { 83,0x56},
    { 84,0x1C},
    { 85,0x03},
    { 86,0xE0},
    { 87,0x6D},
    { 88,0x1C},
    { 89,0x04},
    { 90,0x00},
    { 91,0x52},
    { 92,0x1C},
    { 93,0x04},
    { 94,0x00},
    { 95,0x71},
    { 96,0x1C},
    { 97,0x04},
    { 98,0x20},
    { 99,0x5A},
    {100,0x1C},
    {101,0x04},
    {102,0x20},
    {103,0x69},
    {104,0x1C},
    {105,0x04},
    {106,0x40},
    {107,0x5E},
    {108,0x1C},
    {109,0x04},
    {110,0x40},
    {111,0x65},
    {112,0x1C},
    {113,0x04},
    {114,0x60},
    {115,0x60},
    {116,0x1C},
    {117,0x04},
    {118,0x60},
    {119,0x63},
    {120,0x1C},
    {121,0x04},
    {122,0x80},
    {123,0x61},
    {124,0x1C},
    {125,0x04},
    {126,0x80},
    {127,0x62},
    {  0,0x07},
    {  8,0x00},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0x00},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x10},
    { 21,0x00},
    { 22,0x00},
    { 23,0x79},
    { 24,0x18},
    { 25,0x04},
    { 26,0xC0},
    { 27,0x78},
    { 28,0x1C},
    { 29,0x04},
    { 30,0xE0},
    { 31,0x7A},
    { 32,0x1C},
    { 33,0x04},
    { 34,0xE0},
    { 35,0x77},
    { 36,0x1C},
    { 37,0x04},
    { 38,0xC0},
    { 39,0x79},
    { 40,0x1C},
    { 41,0x05},
    { 42,0x00},
    { 43,0x76},
    { 44,0x1C},
    { 45,0x05},
    { 46,0x00},
    { 47,0x7B},
    { 48,0x1C},
    { 49,0x05},
    { 50,0x20},
    { 51,0x75},
    { 52,0x1C},
    { 53,0x05},
    { 54,0x20},
    { 55,0x7C},
    { 56,0x18},
    { 57,0x05},
    { 58,0x80},
    { 59,0x7D},
    { 60,0x1C},
    { 61,0x05},
    { 62,0x80},
    { 63,0x7F},
    { 64,0x1C},
    { 65,0x05},
    { 66,0x60},
    { 67,0x82},
    { 68,0x4C},
    { 69,0x05},
    { 70,0x60},
    { 71,0x80},
    { 72,0x00},
    { 73,0x00},
    { 74,0x00},
    { 75,0x00},
    { 76,0x5C},
    { 77,0x90},
    { 78,0x60},
    { 79,0x03},
    { 80,0x18},
    { 81,0x04},
    { 82,0xC0},
    { 83,0x38},
    { 84,0x1C},
    { 85,0x04},
    { 86,0xC0},
    { 87,0x39},
    { 88,0x1C},
    { 89,0x04},
    { 90,0xE0},
    { 91,0x3A},
    { 92,0x10},
    { 93,0x00},
    { 94,0x40},
    { 95,0x89},
    { 96,0x1C},
    { 97,0x04},
    { 98,0xE0},
    { 99,0x37},
    {100,0x1C},
    {101,0x05},
    {102,0x00},
    {103,0x36},
    {104,0x1C},
    {105,0x05},
    {106,0x00},
    {107,0x3B},
    {108,0x1C},
    {109,0x05},
    {110,0x20},
    {111,0x35},
    {112,0x1C},
    {113,0x05},
    {114,0x20},
    {115,0x3C},
    {116,0x18},
    {117,0x05},
    {118,0x80},
    {119,0x3D},
    {120,0x1C},
    {121,0x05},
    {122,0x80},
    {123,0x3F},
    {124,0x1C},
    {125,0x05},
    {126,0x60},
    {127,0x42},
    {  0,0x08},
    {  8,0x4C},
    {  9,0x05},
    { 10,0x60},
    { 11,0x40},
    { 12,0x00},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x5C},
    { 17,0x90},
    { 18,0x40},
    { 19,0x03},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x00},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x00},
    { 29,0x00},
    { 30,0x00},
    { 31,0x00},
    { 32,0x10},
    { 33,0x00},
    { 34,0x40},
    { 35,0x49},
    { 36,0x18},
    { 37,0x05},
    { 38,0xA0},
    { 39,0x80},
    { 40,0x1C},
    { 41,0x05},
    { 42,0xA0},
    { 43,0x7F},
    { 44,0x1C},
    { 45,0x05},
    { 46,0xC0},
    { 47,0x7D},
    { 48,0x00},
    { 49,0x00},
    { 50,0x00},
    { 51,0x00},
    { 52,0x5C},
    { 53,0x90},
    { 54,0x60},
    { 55,0x03},
    { 56,0x18},
    { 57,0x05},
    { 58,0xA0},
    { 59,0x40},
    { 60,0x1C},
    { 61,0x05},
    { 62,0xA0},
    { 63,0x3F},
    { 64,0x1C},
    { 65,0x05},
    { 66,0xC0},
    { 67,0x3D},
    { 68,0x10},
    { 69,0x00},
    { 70,0x40},
    { 71,0x88},
    { 72,0x18},
    { 73,0x05},
    { 74,0x40},
    { 75,0x76},
    { 76,0x5C},
    { 77,0x90},
    { 78,0x40},
    { 79,0x03},
    { 80,0x18},
    { 81,0x05},
    { 82,0x60},
    { 83,0x7F},
    { 84,0x1C},
    { 85,0x05},
    { 86,0x80},
    { 87,0x80},
    { 88,0x4C},
    { 89,0x05},
    { 90,0x60},
    { 91,0x81},
    { 92,0x10},
    { 93,0x00},
    { 94,0x40},
    { 95,0x48},
    { 96,0x1C},
    { 97,0x05},
    { 98,0x80},
    { 99,0x7D},
    {100,0x18},
    {101,0x05},
    {102,0x40},
    {103,0x36},
    {104,0x5C},
    {105,0x90},
    {106,0x60},
    {107,0x03},
    {108,0x18},
    {109,0x05},
    {110,0x60},
    {111,0x3F},
    {112,0x1C},
    {113,0x05},
    {114,0x80},
    {115,0x40},
    {116,0x4C},
    {117,0x05},
    {118,0x60},
    {119,0x41},
    {120,0x10},
    {121,0x00},
    {122,0x40},
    {123,0x87},
    {124,0x1C},
    {125,0x05},
    {126,0x80},
    {127,0x3D},
    {  0,0x09},
    {  8,0x00},
    {  9,0x00},
    { 10,0x00},
    { 11,0x00},
    { 12,0x5C},
    { 13,0x90},
    { 14,0x40},
    { 15,0x03},
    { 16,0x18},
    { 17,0x05},
    { 18,0xA0},
    { 19,0x81},
    { 20,0x1C},
    { 21,0x05},
    { 22,0xA0},
    { 23,0x7D},
    { 24,0x1C},
    { 25,0x05},
    { 26,0xC0},
    { 27,0x80},
    { 28,0x10},
    { 29,0x00},
    { 30,0x40},
    { 31,0x47},
    { 32,0x5C},
    { 33,0x90},
    { 34,0x60},
    { 35,0x03},
    { 36,0x00},
    { 37,0x00},
    { 38,0x00},
    { 39,0x00},
    { 40,0x00},
    { 41,0x00},
    { 42,0x00},
    { 43,0x00},
    { 44,0x00},
    { 45,0x00},
    { 46,0x00},
    { 47,0x00},
    { 48,0x10},
    { 49,0x00},
    { 50,0x40},
    { 51,0x86},
    { 52,0x18},
    { 53,0x05},
    { 54,0xA0},
    { 55,0x41},
    { 56,0x1C},
    { 57,0x05},
    { 58,0xA0},
    { 59,0x3D},
    { 60,0x1C},
    { 61,0x05},
    { 62,0xC0},
    { 63,0x40},
    { 64,0x18},
    { 65,0x04},
    { 66,0xA0},
    { 67,0x61},
    { 68,0x5C},
    { 69,0x90},
    { 70,0x40},
    { 71,0x03},
    { 72,0x18},
    { 73,0x04},
    { 74,0xC0},
    { 75,0x7C},
    { 76,0x1C},
    { 77,0x04},
    { 78,0xE0},
    { 79,0x75},
    { 80,0x4C},
    { 81,0x04},
    { 82,0xC0},
    { 83,0x74},
    { 84,0x10},
    { 85,0x00},
    { 86,0x40},
    { 87,0x46},
    { 88,0x1C},
    { 89,0x04},
    { 90,0xE0},
    { 91,0x7B},
    { 92,0x1C},
    { 93,0x05},
    { 94,0x00},
    { 95,0x7A},
    { 96,0x1C},
    { 97,0x05},
    { 98,0x00},
    { 99,0x76},
    {100,0x1C},
    {101,0x05},
    {102,0x20},
    {103,0x79},
    {104,0x1C},
    {105,0x05},
    {106,0x20},
    {107,0x77},
    {108,0x18},
    {109,0x05},
    {110,0x80},
    {111,0x81},
    {112,0x1C},
    {113,0x05},
    {114,0x80},
    {115,0x80},
    {116,0x1C},
    {117,0x05},
    {118,0x60},
    {119,0x7D},
    {120,0x4C},
    {121,0x05},
    {122,0x60},
    {123,0x7E},
    {124,0x18},
    {125,0x04},
    {126,0xA0},
    {127,0x21},
    {  0,0x0A},
    {  8,0x5C},
    {  9,0x90},
    { 10,0x60},
    { 11,0x03},
    { 12,0x18},
    { 13,0x04},
    { 14,0xC0},
    { 15,0x3C},
    { 16,0x1C},
    { 17,0x04},
    { 18,0xE0},
    { 19,0x35},
    { 20,0x4C},
    { 21,0x04},
    { 22,0xC0},
    { 23,0x34},
    { 24,0x10},
    { 25,0x00},
    { 26,0x40},
    { 27,0x85},
    { 28,0x1C},
    { 29,0x04},
    { 30,0xE0},
    { 31,0x3B},
    { 32,0x1C},
    { 33,0x05},
    { 34,0x00},
    { 35,0x3A},
    { 36,0x1C},
    { 37,0x05},
    { 38,0x00},
    { 39,0x36},
    { 40,0x1C},
    { 41,0x05},
    { 42,0x20},
    { 43,0x39},
    { 44,0x1C},
    { 45,0x05},
    { 46,0x20},
    { 47,0x37},
    { 48,0x18},
    { 49,0x05},
    { 50,0x80},
    { 51,0x41},
    { 52,0x1C},
    { 53,0x05},
    { 54,0x80},
    { 55,0x40},
    { 56,0x1C},
    { 57,0x05},
    { 58,0x60},
    { 59,0x3D},
    { 60,0x4C},
    { 61,0x05},
    { 62,0x60},
    { 63,0x3E},
    { 64,0x00},
    { 65,0x00},
    { 66,0x00},
    { 67,0x00},
    { 68,0x5C},
    { 69,0x90},
    { 70,0x40},
    { 71,0x03},
    { 72,0x00},
    { 73,0x00},
    { 74,0x00},
    { 75,0x00},
    { 76,0x00},
    { 77,0x00},
    { 78,0x00},
    { 79,0x00},
    { 80,0x00},
    { 81,0x00},
    { 82,0x00},
    { 83,0x00},
    { 84,0x10},
    { 85,0x00},
    { 86,0x40},
    { 87,0x44},
    { 88,0x18},
    { 89,0x05},
    { 90,0xA0},
    { 91,0x7E},
    { 92,0x1C},
    { 93,0x05},
    { 94,0xA0},
    { 95,0x80},
    { 96,0x1C},
    { 97,0x05},
    { 98,0xC0},
    { 99,0x81},
    {100,0x10},
    {101,0x00},
    {102,0x40},
    {103,0x45},
    {104,0x00},
    {105,0x00},
    {106,0x00},
    {107,0x00},
    {108,0x5C},
    {109,0x90},
    {110,0x60},
    {111,0x03},
    {112,0x18},
    {113,0x05},
    {114,0xA0},
    {115,0x3E},
    {116,0x1C},
    {117,0x05},
    {118,0xA0},
    {119,0x40},
    {120,0x1C},
    {121,0x05},
    {122,0xC0},
    {123,0x41},
    {124,0x10},
    {125,0x00},
    {126,0x40},
    {127,0x84},
    {  0,0x0B},
    {  8,0x18},
    {  9,0x05},
    { 10,0x40},
    { 11,0x7A},
    { 12,0x5C},
    { 13,0x90},
    { 14,0x40},
    { 15,0x03},
    { 16,0x18},
    { 17,0x05},
    { 18,0x60},
    { 19,0x80},
    { 20,0x1C},
    { 21,0x05},
    { 22,0x80},
    { 23,0x7E},
    { 24,0x4C},
    { 25,0x05},
    { 26,0x60},
    { 27,0x7C},
    { 28,0x10},
    { 29,0x00},
    { 30,0x40},
    { 31,0x44},
    { 32,0x1C},
    { 33,0x05},
    { 34,0x80},
    { 35,0x81},
    { 36,0x18},
    { 37,0x05},
    { 38,0x40},
    { 39,0x3A},
    { 40,0x5C},
    { 41,0x90},
    { 42,0x60},
    { 43,0x03},
    { 44,0x18},
    { 45,0x05},
    { 46,0x60},
    { 47,0x40},
    { 48,0x1C},
    { 49,0x05},
    { 50,0x80},
    { 51,0x3E},
    { 52,0x4C},
    { 53,0x05},
    { 54,0x60},
    { 55,0x3C},
    { 56,0x10},
    { 57,0x00},
    { 58,0x40},
    { 59,0x83},
    { 60,0x1C},
    { 61,0x05},
    { 62,0x80},
    { 63,0x41},
    { 64,0x00},
    { 65,0x00},
    { 66,0x00},
    { 67,0x00},
    { 68,0x5C},
    { 69,0x90},
    { 70,0x40},
    { 71,0x03},
    { 72,0x18},
    { 73,0x05},
    { 74,0xA0},
    { 75,0x7C},
    { 76,0x1C},
    { 77,0x05},
    { 78,0xA0},
    { 79,0x81},
    { 80,0x1C},
    { 81,0x05},
    { 82,0xC0},
    { 83,0x7E},
    { 84,0x10},
    { 85,0x00},
    { 86,0x40},
    { 87,0x43},
    { 88,0x00},
    { 89,0x00},
    { 90,0x00},
    { 91,0x00},
    { 92,0x5C},
    { 93,0x90},
    { 94,0x60},
    { 95,0x03},
    { 96,0x18},
    { 97,0x05},
    { 98,0xA0},
    { 99,0x3C},
    {100,0x1C},
    {101,0x05},
    {102,0xA0},
    {103,0x41},
    {104,0x1C},
    {105,0x05},
    {106,0xC0},
    {107,0x3E},
    {108,0x10},
    {109,0x00},
    {110,0x40},
    {111,0x82},
    {112,0x5C},
    {113,0x90},
    {114,0x40},
    {115,0x03},
    {116,0x00},
    {117,0x00},
    {118,0x00},
    {119,0x00},
    {120,0x00},
    {121,0x00},
    {122,0x00},
    {123,0x00},
    {124,0x00},
    {125,0x00},
    {126,0x00},
    {127,0x00},
    {  0,0x0C},
    {  8,0x10},
    {  9,0x00},
    { 10,0x40},
    { 11,0x42},
    { 12,0x00},
    { 13,0x00},
    { 14,0x00},
    { 15,0x00},
    { 16,0x00},
    { 17,0x00},
    { 18,0x00},
    { 19,0x00},
    { 20,0x00},
    { 21,0x00},
    { 22,0x00},
    { 23,0x00},
    { 24,0x02},
    { 25,0x00},
    { 26,0x00},
    { 27,0x00},
    { 28,0x00},
    { 29,0x00},
    { 30,0x00},
    { 31,0x00},
};
#define miniDSP_D_reg_values_COEFF_START   0
#define miniDSP_D_reg_values_COEFF_SIZE    394
#define miniDSP_D_reg_values_INST_START    394
#define miniDSP_D_reg_values_INST_SIZE     1358
